Count data of size, shape and orientation values.
binning3d(size, angle, shape, breaks, check = TRUE, na.rm = TRUE)vector of sizes
vector of angles
vector of aspect ratios
list of bin vectors
logical, default is TRUE
logical, if NAs are to be removed in the data vectors, default is TRUE
3d array of count data
For each value of planar or spatial measured quantities size,shape,orientation
the function counts the number of observations falling into each class.
The breaks list is either obtained from function setbreaks or the
user supplies his own variant, see setbreaks for details.
If check is TRUE some checks on the breaks list are done.