Learn R Programming

unfoldr (version 0.6.5)

cylinderIntersection: Cylinder vertical intersection

Description

Intersect a clyinder system by a vertical section plane

Usage

cylinderIntersection(S, d, n = c(0, 1, 0), intern = FALSE)

Arguments

S

list of cylinders, see simCylinderSystem

d

distance of intersecting plane to the origin

n

normal vector of intersting plane

intern

intern=FALSE (default) return all section profiles otherwise only those which have their centers inside the intersection window

Value

list of size, shape and angle of section profiles

Details

The function performs a vertical intersection defined by the normal vector n=c(0,1,0) which depends on the main orientation axis of the coordinate system and has to be parallel to this.