Extract the original 3d size-shape-orientation parameters
Usage
parameters3d(S)
Arguments
S
list of spheroids
Value
list
Details
The function simply extracts the parameters for the original 3d spheroid system
either for oblate or prolate spheroids and returns a list which consists of sizes
a, the orientation angles Theta and the shape parameters s.