planarSection: Sphere planar section
Description
Intersect sphere system
Usage
planarSection(S, d, intern = FALSE)
Arguments
d
distance of the intersecting xy-plane to the origin
intern
intern=FALSE (default) return all sections otherwise
only those which have their centers inside the intersection window
Value
vector of circle radii
Details
Given a sphere system obtained from simSphereSystem
the function returns the section radii from intersecting all spheres
stored in S.