Plot trivariate histogram of size, shape, orientation distribution
trivarHist(A, main = paste("Trivariate Histogram"), scale = 0.5, col, ...)3d array of count data
main title
factor to scale the spheres
vector of color values repeatedly used
optional graphic arguments
the graphical output: trivariate histogram
The (estimated spatial) joint size-shape-orientation distribution is plotted in a box with corresponding axes shown. The axes intersect in the first class number. The ball volumes visualize the relative frequencies of count data for each class which can be scaled by the user for non-overlapping spheres. Balls within the same size class have the same color.