Intersect a clyinder system by a vertical section plane
cylinderIntersection(S, d, n = c(0, 1, 0), intern = FALSE)list of cylinders, see simCylinderSystem
distance of intersecting plane to the origin
normal vector of intersting plane
intern=FALSE (default) return all section profiles otherwise
only those which have their centers inside the intersection window
list of size, shape and angle of section profiles
The function performs a vertical intersection defined by the normal vector
n=c(0,1,0) which depends on the main orientation axis of the
coordinate system and has to be parallel to this.