unfold: Stereological unfolding
Description
Unfolding the (joint) distribution of planar parametersUsage
unfold(sp, nclass, maxIt = 64, nCores = getOption("par.unfoldr", 1), ...)Arguments
maxIt
maximum number of EM iterations
nCores
number of cpu cores used
Details
This is a S3 method for either trivariate stereological unfolding or
estimation of 3d diameter distribution of spheres (Wicksell's corpuscle problem). The function
aggregates all intermediate calculation steps required for the unfolding procedure given the data
in the prescribed format and returning the parameters as count data in histogram form.
The section profiles object sp, see sectionProfiles, is either of class
prolate or oblate for the reconstruction of spheroids or in case of spheres
the sp is simply a numeric vector of circle diameters. Here, the class of section profiles
corresponds to the type of objects that will be reconstructed. The number of bin classes is set
by the argument nclass which is either a scalar value in case of Wicksell's corpuscle problem
or a vector of length three defined in the order of the number of size, angle and shape class limits.
Using multiple cpu cores during the calculations is controlled by either setting the option 'par.unfoldr'
to a user chosen amount of cores or by the argument nCores directly.
The return value of the function is an object of class unfold whose arguments are as follows
{ (trivariate) histogram of section profile parameters}
- N_V
{ (trivariate) histogram of reconstructed parameters}
- P
{ array of coefficients}
- breaks
{ list of class limits for binning the parameter values}